@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: SQLite setup/teardown for tests
 
-our $VERSION = '0.0205';
+our $VERSION = '0.0206';
 
 use Moo;
 use strictures 2;
@@ -72,8 +72,8 @@ sub _build__database {
         open my $schema, '<', $self->schema
             or die "Can't read " . $self->schema . ": $!";
 
-        my $dbh = DBI->connect( 'dbi:SQLite:dbname=' . $filename, '', '', { RaiseError => 1, AutoCommit => 0 } )
-            or die "Failed to open DB $filename: " . $DBI::errstr;
+        my $dbh = DBI->connect( "dbi:SQLite:dbname=$filename", '', '', { RaiseError => 1, AutoCommit => 0 } )
+            or die "Can't connect to $filename: " . $DBI::errstr;
 
         my $sql = '';
         while ( my $line = readline($schema) ) {
@@ -121,7 +121,7 @@ Test::SQLite - SQLite setup/teardown for tests
 
 =head1 VERSION
 
-version 0.0205
+version 0.0206
 
 =head1 SYNOPSIS
 
@@ -165,6 +165,8 @@ The SQL schema to create a test database.
 
 Boolean indicating that a schema file was provided to the constructor.
 
+* The SQL parsing done by this module does not handle triggers.
+
 =head2 db_attrs
 
 DBI connection attributes.  Default: { RaiseError => 1, AutoCommit => 1 }
@@ -184,7 +186,7 @@ A connected database handle based on the B<dsn> and B<db_attrs>.
   $sqlite = Test::SQLite->new(%arguments);
 
 Create a new C<Test::SQLite> object, which creates a temporary
-database based on the given B<database> or B<schema>.
+database given a B<database> or B<schema>.
 
 =head2 BUILD
 
